==> jbossxts-4.17.15.Final-sources.jar: com/arjuna/mwlabs/wscf/model/twophase/arjunacore/CoordinatorIdImple.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. 
 * See the copyright.txt in the distribution for a full listing 
 * of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 * 
 * (C) 2005-2006,
 * @author JBoss Inc.
 */
/*
 * Copyright (C) 2002,
 *
 * Arjuna Technologies Limited,
 * Newcastle upon Tyne,
 * Tyne and Wear,
 * UK.
 *
 * $Id: CoordinatorIdImple.java,v 1.3 2004/03/15 13:25:13 nmcl Exp $
 */

package com.arjuna.mwlabs.wscf.model.twophase.arjunacore;

import com.arjuna.ats.arjuna.common.Uid;

import com.arjuna.mw.wscf.common.CoordinatorId;

/**
 * This implementation of CoordinatorId uses the ArjunaCore Uid class.
 *
 * @author Mark Little (mark.little@arjuna.com)
 * @version $Id: CoordinatorIdImple.java,v 1.3 2004/03/15 13:25:13 nmcl Exp $
 * @since 1.0.
 */

public class CoordinatorIdImple extends Uid implements CoordinatorId
{

    public CoordinatorIdImple ()
    {
	super();

	_value = stringForm().getBytes();
    }
    
    public CoordinatorIdImple (String id)
    {
	super(id);

	_value = stringForm().getBytes();
    }

    public CoordinatorIdImple (Uid id)
    {
	super(id);

	_value = stringForm().getBytes();
    }
    
    public byte[] value ()
    {
	return _value;
    }
    
    private byte[] _value;
    
}

==> jbossxts-5.6.4.Final-sources.jar: com/arjuna/mwlabs/wscf/model/twophase/arjunacore/CoordinatorIdImple.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. 
 * See the copyright.txt in the distribution for a full listing 
 * of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 * 
 * (C) 2005-2006,
 * @author JBoss Inc.
 */
/*
 * Copyright (C) 2002,
 *
 * Arjuna Technologies Limited,
 * Newcastle upon Tyne,
 * Tyne and Wear,
 * UK.
 *
 * $Id: CoordinatorIdImple.java,v 1.3 2004/03/15 13:25:13 nmcl Exp $
 */

package com.arjuna.mwlabs.wscf.model.twophase.arjunacore;

import java.nio.charset.StandardCharsets;

import com.arjuna.ats.arjuna.common.Uid;

import com.arjuna.mw.wscf.common.CoordinatorId;

/**
 * This implementation of CoordinatorId uses the ArjunaCore Uid class.
 *
 * @author Mark Little (mark.little@arjuna.com)
 * @version $Id: CoordinatorIdImple.java,v 1.3 2004/03/15 13:25:13 nmcl Exp $
 * @since 1.0.
 */

public class CoordinatorIdImple extends Uid implements CoordinatorId
{

    public CoordinatorIdImple ()
    {
	super();

	_value = stringForm().getBytes();
    }
    
    public CoordinatorIdImple (String id)
    {
	super(id);

	_value = stringForm().getBytes(StandardCharsets.UTF_8);
    }

    public CoordinatorIdImple (Uid id)
    {
	super(id);

	_value = stringForm().getBytes(StandardCharsets.UTF_8);
    }
    
    public byte[] value ()
    {
	return _value;
    }
    
    private byte[] _value;
    
}
